==> huaweicloudsdkccm-3.0.51-py2.py3-none-any.whl: huaweicloudsdkccm/v1/model/delete_certificate_authority_request.py <==
# coding: utf-8

import re
import six





class DeleteCertificateAuthorityRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'ca_id': 'str',
        'pending_days': 'str'
    }

    attribute_map = {
        'ca_id': 'ca_id',
        'pending_days': 'pending_days'
    }

    def __init__(self, ca_id=None, pending_days=None):
        """DeleteCertificateAuthorityRequest - a model defined in huaweicloud sdk"""
        
        

        self._ca_id = None
        self._pending_days = None
        self.discriminator = None

        self.ca_id = ca_id
        self.pending_days = pending_days

    @property
    def ca_id(self):
        """Gets the ca_id of this DeleteCertificateAuthorityRequest.

        ca_id

        :return: The ca_id of this DeleteCertificateAuthorityRequest.
        :rtype: str
        """
        return self._ca_id

    @ca_id.setter
    def ca_id(self, ca_id):
        """Sets the ca_id of this DeleteCertificateAuthorityRequest.

        ca_id

        :param ca_id: The ca_id of this DeleteCertificateAuthorityRequest.
        :type: str
        """
        self._ca_id = ca_id

    @property
    def pending_days(self):
        """Gets the pending_days of this DeleteCertificateAuthorityRequest.

        pending_days

        :return: The pending_days of this DeleteCertificateAuthorityRequest.
        :rtype: str
        """
        return self._pending_days

    @pending_days.setter
    def pending_days(self, pending_days):
        """Sets the pending_days of this DeleteCertificateAuthorityRequest.

        pending_days

        :param pending_days: The pending_days of this DeleteCertificateAuthorityRequest.
        :type: str
        """
        self._pending_days = pending_days

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteCertificateAuthorityRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkccm-3.0.53-py2.py3-none-any.whl: huaweicloudsdkccm/v1/model/delete_certificate_authority_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteCertificateAuthorityRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'ca_id': 'str',
        'pending_days': 'str'
    }

    attribute_map = {
        'ca_id': 'ca_id',
        'pending_days': 'pending_days'
    }

    def __init__(self, ca_id=None, pending_days=None):
        """DeleteCertificateAuthorityRequest - a model defined in huaweicloud sdk"""
        
        

        self._ca_id = None
        self._pending_days = None
        self.discriminator = None

        self.ca_id = ca_id
        self.pending_days = pending_days

    @property
    def ca_id(self):
        """Gets the ca_id of this DeleteCertificateAuthorityRequest.

        ca_id

        :return: The ca_id of this DeleteCertificateAuthorityRequest.
        :rtype: str
        """
        return self._ca_id

    @ca_id.setter
    def ca_id(self, ca_id):
        """Sets the ca_id of this DeleteCertificateAuthorityRequest.

        ca_id

        :param ca_id: The ca_id of this DeleteCertificateAuthorityRequest.
        :type: str
        """
        self._ca_id = ca_id

    @property
    def pending_days(self):
        """Gets the pending_days of this DeleteCertificateAuthorityRequest.

        pending_days

        :return: The pending_days of this DeleteCertificateAuthorityRequest.
        :rtype: str
        """
        return self._pending_days

    @pending_days.setter
    def pending_days(self, pending_days):
        """Sets the pending_days of this DeleteCertificateAuthorityRequest.

        pending_days

        :param pending_days: The pending_days of this DeleteCertificateAuthorityRequest.
        :type: str
        """
        self._pending_days = pending_days

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteCertificateAuthorityRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
